"""
$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/qpy/__init__.py $
$Id: __init__.py 27625 2005-10-26 22:23:20Z dbinger $
"""

# external code should import these from here.
from qpy.c8 import u8, h8, stringify, html_escape_string 
[u8, h8, stringify, html_escape_string] # for qpcheck.py.


